﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;

namespace SampleTG
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            this.Loaded += MainWindow_Loaded;
        }

        void MainWindow_Loaded(object sender, RoutedEventArgs e)
        {
            wpfMap1.MapUnit = GeographyUnit.Meter;

            OpenStreetMapOverlay openStreetMapOverlay = new OpenStreetMapOverlay();
            wpfMap1.Overlays.Add("OpenStreetMap", openStreetMapOverlay);

            string path = @"..\..\SampleData\Sample.shp";

            ShapeFileFeatureLayer shapeFileLayer = new ShapeFileFeatureLayer(path, ShapeFileReadWriteMode.ReadOnly);
            shapeFileLayer.RequireIndex = true;
            ((ShapeFileFeatureSource)shapeFileLayer.FeatureSource).StreamLoading += new EventHandler<StreamLoadingEventArgs>(StreamLoading);

            Proj4Projection managedProj4 = new Proj4Projection();
            managedProj4.InternalProjectionParametersString = ManagedProj4Projection.GetEpsgParametersString(27700);
            managedProj4.ExternalProjectionParametersString = ManagedProj4Projection.GetGoogleMapParametersString();
            shapeFileLayer.FeatureSource.Projection = managedProj4;

            shapeFileLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1;
            shapeFileLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = LineStyles.Equator1;
            shapeFileLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.City2;
            shapeFileLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            LayerOverlay overlay = new LayerOverlay();

            overlay.Layers.Add("shapelayer", shapeFileLayer);
            wpfMap1.Overlays.Add("shapeOverlay", overlay);

            shapeFileLayer.Open();
            wpfMap1.CurrentExtent = shapeFileLayer.GetBoundingBox();
            shapeFileLayer.Close();

            wpfMap1.Refresh();
        }
        private static void StreamLoading(object sender, StreamLoadingEventArgs e)
        {
            try
            {
                string fileName = System.IO.Path.GetFileName(e.AlternateStreamName);
                string Directory = System.IO.Path.GetDirectoryName(e.AlternateStreamName);

                if (File.Exists(Directory + @"\\" + fileName)) e.AlternateStream = new FileStream(Directory + @"\\" + fileName, e.FileMode, e.FileAccess);
                else e.AlternateStream = null;
            }
            catch
            {
            }
        }
    }
}